import {
  select,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisBottom,
  axisLeft,
  csv,
  schemeRdYlBu
} from 'd3';



import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { scatterPlot } from './scatterPlot';


const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(860,80)`);


const colorScale = scaleOrdinal();
const colorValue = d => d.Year;



const title = 'London Monthly Air Quality: PM2.5 vs. PM10 Particulates';
const xValue = d => d['Roadside_PM2.5'];
const xAxisLabel = 'Roadside PM2.5 (ug/m3)';

  
const yValue = d => d.cylinders;
const circleRadius = 10;
const yAxisLabel = 'Roadside PM10 (ug/m3)';

  
const margin = { top: 60, right: 130, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

let data;
let selectedColorValue;


const onClick = d => {
  selectedColorValue = d;
  render();
}

loadAndProcessData()
  .then(d => {
    data = d
    render()
});


const render = () => {
  colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
    .range(schemeRdYlBu[colorScale.domain().length]); 

    scatterPlotG.call(scatterPlot,{
      data,
      colorValue,
      colorScale,
      selectedColorValue,
      width,
      height,
      margin,
      title,
      xValue,
      xAxisLabel,
      yValue,
      yAxisLabel, 
      circleRadius,
      innerWidth,
      innerHeight
      });

  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 10,
    spacing: 21,
    textOffset: 16,
    backgroundRectWidth:85,
    onClick,
    selectedColorValue
  });
};






import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Cars: Horsepower vs. Weight';
  
  const xValue = d => d.horsepower;
  const xAxisLabel = 'Horsepower';
  
  const yValue = d => d.weight;
  const circleRadius = 10;
  const yAxisLabel = 'Weight';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;  
    });
    render(data);
  });